@@ -41,6 +41,8 @@
 #include "actions/layeradd.h"
 #include "actions/layeractivate.h"
 #include "actions/layerparamset.h"
+#include "actions/layerparamsetstatic.h"
+#include "actions/layerparamunsetstatic.h"
 #include "actions/layerparamconnect.h"
 #include "actions/layerparamdisconnect.h"
 #include "actions/layerencapsulate.h"
@@ -48,6 +50,8 @@
 #include "actions/layersetdesc.h"
 
 #include "actions/valuenodeconstset.h"
+#include "actions/valuenodeconstsetstatic.h"
+#include "actions/valuenodeconstunsetstatic.h"
 #include "actions/valuenodeadd.h"
 #include "actions/valuenodereplace.h"
 #include "actions/valuenodelinkconnect.h"
@@ -69,6 +73,7 @@
 #include "actions/valuedescdisconnect.h"
 #include "actions/valuedesclink.h"
 #include "actions/valuedescblinelink.h"
+#include "actions/valuedescremovesmart.h"
 
 #include "actions/waypointadd.h"
 #include "actions/waypointset.h"
@@ -99,6 +104,8 @@
 
 #include "actions/canvasdescriptionset.h"
 #include "actions/canvasidset.h"
+#include "actions/canvasmetadataerase.h"
+#include "actions/canvasmetadataset.h"
 #include "actions/canvasnameset.h"
 #include "actions/canvasrenddescset.h"
 #include "actions/canvasadd.h"
@@ -161,6 +168,8 @@ Action::Main::Main()
 	ADD_ACTION(Action::LayerAdd);
 	ADD_ACTION(Action::LayerActivate);
 	ADD_ACTION(Action::LayerParamSet);
+	ADD_ACTION(Action::LayerParamSetStatic);
+	ADD_ACTION(Action::LayerParamUnSetStatic);
 	ADD_ACTION(Action::LayerParamConnect);
 	ADD_ACTION(Action::LayerParamDisconnect);
 	ADD_ACTION(Action::LayerEncapsulate);
@@ -168,6 +177,8 @@ Action::Main::Main()
 	ADD_ACTION(Action::LayerSetDesc);
 
 	ADD_ACTION(Action::ValueNodeConstSet);
+	ADD_ACTION(Action::ValueNodeConstSetStatic);
+	ADD_ACTION(Action::ValueNodeConstUnSetStatic);
 	ADD_ACTION(Action::ValueNodeAdd);
 	ADD_ACTION(Action::ValueNodeReplace);
 	ADD_ACTION(Action::ValueNodeLinkConnect);
@@ -188,7 +199,9 @@ Action::Main::Main()
 	ADD_ACTION(Action::ValueDescConnect);
 	ADD_ACTION(Action::ValueDescDisconnect);
 	ADD_ACTION(Action::ValueDescLink);
+	ADD_ACTION(Action::ValueDescLinkOpposite);
 	ADD_ACTION(Action::ValueDescBLineLink);
+	ADD_ACTION(Action::ValueDescRemoveSmart);
 
 	ADD_ACTION(Action::WaypointAdd);
 	ADD_ACTION(Action::WaypointSet);
@@ -215,7 +228,9 @@ Action::Main::Main()
 
 	ADD_ACTION(Action::CanvasDescriptionSet);
 	ADD_ACTION(Action::CanvasIdSet);
-	ADD_ACTION(Action::CanvasNameSet);
+	ADD_ACTION(Action::CanvasNameSet)
+	ADD_ACTION(Action::CanvasMetadataErase);;
+	ADD_ACTION(Action::CanvasMetadataSet);
 	ADD_ACTION(Action::CanvasRendDescSet);
 	ADD_ACTION(Action::CanvasAdd);
 	ADD_ACTION(Action::CanvasRemove);
