@@ -2,7 +2,7 @@
 /*!	\file keyframeremove.cpp
 **	\brief Template File
 **
-**	$Id: keyframeremove.cpp 1143 2007-11-13 09:13:07Z pabs $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -49,13 +49,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::KeyframeRemove);
-ACTION_SET_NAME(Action::KeyframeRemove,"keyframe_remove");
+ACTION_SET_NAME(Action::KeyframeRemove,"KeyframeRemove");
 ACTION_SET_LOCAL_NAME(Action::KeyframeRemove,N_("Remove Keyframe"));
 ACTION_SET_TASK(Action::KeyframeRemove,"remove");
 ACTION_SET_CATEGORY(Action::KeyframeRemove,Action::CATEGORY_KEYFRAME);
 ACTION_SET_PRIORITY(Action::KeyframeRemove,0);
 ACTION_SET_VERSION(Action::KeyframeRemove,"0.0");
-ACTION_SET_CVS_ID(Action::KeyframeRemove,"$Id: keyframeremove.cpp 1143 2007-11-13 09:13:07Z pabs $");
+ACTION_SET_CVS_ID(Action::KeyframeRemove,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
