@@ -2,7 +2,7 @@
 /*!	\file layerparamdisconnect.cpp
 **	\brief Template File
 **
-**	$Id: layerparamdisconnect.cpp 1143 2007-11-13 09:13:07Z pabs $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -46,13 +46,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::LayerParamDisconnect);
-ACTION_SET_NAME(Action::LayerParamDisconnect,"layer_param_disconnect");
+ACTION_SET_NAME(Action::LayerParamDisconnect,"LayerParamDisconnect");
 ACTION_SET_LOCAL_NAME(Action::LayerParamDisconnect,N_("Disconnect Layer Parameter"));
 ACTION_SET_TASK(Action::LayerParamDisconnect,"disconnect");
 ACTION_SET_CATEGORY(Action::LayerParamDisconnect,Action::CATEGORY_LAYER|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::LayerParamDisconnect,0);
 ACTION_SET_VERSION(Action::LayerParamDisconnect,"0.0");
-ACTION_SET_CVS_ID(Action::LayerParamDisconnect,"$Id: layerparamdisconnect.cpp 1143 2007-11-13 09:13:07Z pabs $");
+ACTION_SET_CVS_ID(Action::LayerParamDisconnect,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
