@@ -104,22 +104,27 @@ Action::ValueDescExport::is_candidate(const ParamList &x)
 	if(candidate_check(get_param_vocab(),x))
 	{
 		ValueDesc value_desc=x.find("value_desc")->second.get_value_desc();
-		if(!value_desc ||
-		   value_desc.parent_is_canvas() ||
-		   (value_desc.is_value_node() && value_desc.get_value_node()->is_exported()) ||
-		   (value_desc.get_value_type()==ValueBase::TYPE_CANVAS && !value_desc.get_value().get(Canvas::Handle())->is_inline()))
+		if(!value_desc)
+			return false;
+		if(value_desc.get_value_type()==ValueBase::TYPE_CANVAS)
+			if(!value_desc.get_value().get(Canvas::Handle()))
+				return false;
+		if(
+			value_desc.parent_is_canvas()
+			||
+			(value_desc.is_value_node() && value_desc.get_value_node()->is_exported())
+			||
+			(value_desc.get_value_type()==ValueBase::TYPE_CANVAS && !value_desc.get_value().get(Canvas::Handle())->is_inline())
+			)
 		{
-//			if (!value_desc)
-//				synfig::info("%s:%d no export because no value_desc", __FILE__, __LINE__);
-//			else if (value_desc.parent_is_canvas())
-//				synfig::info("%s:%d no export because parent is canvas", __FILE__, __LINE__);
-//			else if (value_desc.is_value_node() && value_desc.get_value_node()->is_exported())
-//				synfig::info("%s:%d no export because exported value node", __FILE__, __LINE__);
-//			else if (value_desc.get_value_type()==ValueBase::TYPE_CANVAS && !value_desc.get_value().get(Canvas::Handle())->is_inline())
-//				synfig::info("%s:%d no export because canvas isn't inline", __FILE__, __LINE__);
-
 			return false;
 		}
+	// Don't allow to export lower and upper boundaries of the WidhtPoint
+		if(value_desc.parent_is_linkable_value_node()
+			&& value_desc.get_parent_value_node()->get_name()=="composite"
+			&& value_desc.get_parent_value_node()->get_type()==ValueBase::TYPE_WIDTHPOINT
+			&& (value_desc.get_index()==4 || value_desc.get_index()==5))
+			return false;
 		return true;
 	}
 	return false;
