@@ -2,7 +2,7 @@
 /*!	\file valuenodeadd.cpp
 **	\brief Template File
 **
-**	$Id: valuenodeadd.cpp 1143 2007-11-13 09:13:07Z pabs $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -45,13 +45,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::ValueNodeAdd);
-ACTION_SET_NAME(Action::ValueNodeAdd,"value_node_add");
+ACTION_SET_NAME(Action::ValueNodeAdd,"ValueNodeAdd");
 ACTION_SET_LOCAL_NAME(Action::ValueNodeAdd,N_("Add ValueNode"));
 ACTION_SET_TASK(Action::ValueNodeAdd,"add");
 ACTION_SET_CATEGORY(Action::ValueNodeAdd,Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueNodeAdd,0);
 ACTION_SET_VERSION(Action::ValueNodeAdd,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeAdd,"$Id: valuenodeadd.cpp 1143 2007-11-13 09:13:07Z pabs $");
+ACTION_SET_CVS_ID(Action::ValueNodeAdd,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
