@@ -100,9 +100,13 @@ Action::ValueNodeDynamicListInsert::is_candidate(const ParamList &x)
 
 	ValueDesc value_desc(x.find("value_desc")->second.get_value_desc());
 
-	return (value_desc.parent_is_value_node() &&
-			// We need a dynamic list.
-			ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_parent_value_node()));
+	return ( (value_desc.parent_is_value_node() &&
+			// We need a Dynamic List parent.
+			ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_parent_value_node()))
+			||
+			// Or a Dynamic List value node
+			(value_desc.is_value_node() &&
+			ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_value_node())) );
 }
 
 bool
@@ -113,24 +117,28 @@ Action::ValueNodeDynamicListInsert::set_param(const synfig::String& name, const
 		ValueDesc value_desc(param.get_value_desc());
 
 		if(!value_desc.parent_is_value_node())
+		{
+			if(value_desc.is_value_node())
+			{
+				value_node=ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_value_node());
+				index=0;
+			}
+			else
+				return false;
+		}
+		else
+		{
+			value_node=ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_parent_value_node());
+			index=value_desc.get_index();
+		}
+		if(!value_node) // Not a Dynamic list
 			return false;
-
-		value_node=ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_parent_value_node());
-
-		if(!value_node)
-			return false;
-
-		index=value_desc.get_index();
-
-		value_node_bline=ValueNode_BLine::Handle::cast_dynamic(value_desc.get_parent_value_node());
-
 		list_entry=value_node->create_list_entry(index,time,origin);
 		if(item)
 			list_entry.value_node=item;
-
 		assert(list_entry.value_node.rcount()==1);
-
 		return true;
+
 	}
 	if(name=="time" && param.get_type()==Param::TYPE_TIME)
 	{
