@@ -8,6 +8,7 @@
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
 **	Copyright (c) 2009 Carlos A. Sosa Navarro
+**  Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -43,6 +44,8 @@
 #include <synfig/valuenode_twotone.h>
 #include <synfig/valuenode_stripes.h>
 #include <synfig/valuenode_bline.h>
+#include <synfig/valuenode_wplist.h>
+#include <synfig/valuenode_dilist.h>
 
 #include <synfig/waypoint.h>
 #include <synfig/loadcanvas.h>
@@ -218,16 +221,20 @@ CanvasInterface::add_layer_to(synfig::String name, synfig::Canvas::Handle canvas
 	// Apply some defaults
 	if(layer->set_param("fg",synfigapp::Main::get_outline_color()))
 		layer->set_param("bg",synfigapp::Main::get_fill_color());
-	else if (name == "outline")
+	else if (name == "outline" || name == "advanced_outline")
 		layer->set_param("color",synfigapp::Main::get_outline_color());
 	else
 		layer->set_param("color",synfigapp::Main::get_fill_color());
+	// by default, new advanced outline layers are not homogeneous
+	if(name=="advanced_outline")
+		layer->set_param("homogeneous", false);
 
 	layer->set_param("width",synfigapp::Main::get_bline_width().units(get_canvas()->rend_desc()));
 	layer->set_param("gradient",synfigapp::Main::get_gradient());
 	if(name!="zoom")
 		layer->set_param("amount",synfigapp::Main::get_opacity());
-	layer->set_param("blend_method",synfigapp::Main::get_blend_method());
+	if(synfigapp::Main::get_blend_method() != Color::BLEND_BY_LAYER)
+		layer->set_param("blend_method",synfigapp::Main::get_blend_method());
 
 	{
 		// Grab the layer's list of parameters
@@ -245,7 +252,7 @@ CanvasInterface::add_layer_to(synfig::String name, synfig::Canvas::Handle canvas
 			// bline
 			if(iter->second.get_type()==ValueBase::TYPE_LIST)
 			{
-				// check whether it's a list of blinepoints only
+				// check whether it's a list of blinepoints or widthpoints only
 				vector<ValueBase> list(iter->second.get_list());
 				if (list.size())
 				{
@@ -258,8 +265,24 @@ CanvasInterface::add_layer_to(synfig::String name, synfig::Canvas::Handle canvas
 						value_node=LinkableValueNode::create("bline",iter->second);
 						ValueNode_BLine::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
 					}
+					for (iter2 = list.begin(); iter2 != list.end(); iter2++)
+						if (iter2->get_type() != ValueBase::TYPE_WIDTHPOINT)
+							break;
+					if (iter2 == list.end())
+					{
+						value_node=LinkableValueNode::create("wplist",iter->second);
+						ValueNode_WPList::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
+					}
+					for (iter2 = list.begin(); iter2 != list.end(); iter2++)
+						if (iter2->get_type() != ValueBase::TYPE_DASHITEM)
+							break;
+					if (iter2 == list.end())
+					{
+						value_node=LinkableValueNode::create("dilist",iter->second);
+						ValueNode_DIList::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
+					}
 				}
-
+				// it has something else so just insert the dynamic list
 				if (!value_node)
 					value_node=LinkableValueNode::create("dynamic_list",iter->second);
 			}
@@ -619,6 +642,8 @@ CanvasInterface::import(const synfig::String &filename, synfig::String &errors,
 			throw String(_("Unable to create \"Paste Canvas\" layer"));
 		if(!layer->set_param("canvas",ValueBase(outside_canvas)))
 			throw int();
+		if(!layer->set_param("children_lock",true))
+			throw String(_("Could not set children lock of imported canvas"));
 		get_canvas()->register_external_canvas(filename, outside_canvas);
 
 		//layer->set_description(basename(filename));
@@ -864,9 +889,55 @@ CanvasInterface::change_value(synfigapp::ValueDesc value_desc,synfig::ValueBase
 void
 CanvasInterface::set_meta_data(const synfig::String& key,const synfig::String& data)
 {
-	get_canvas()->set_meta_data(key,data);
+	if (get_canvas()->get_meta_data(key) == data)
+		return;
+
+    if (key=="guide_x" || key=="guide_y")
+	{
+		// Create an undoable action
+
+		synfigapp::Action::Handle action(synfigapp::Action::create("CanvasMetadataSet"));
+
+		assert(action);
+		if(!action)
+			return;
+
+		action->set_param("canvas",get_canvas());
+		action->set_param("canvas_interface",etl::loose_handle<CanvasInterface>(this));
+		action->set_param("key",key);
+		action->set_param("value",data);
+
+		get_instance()->perform_action(action);
+	}
+	else
+	{
+		get_canvas()->set_meta_data(key,data);
+	}
 }
 
+void
+CanvasInterface::erase_meta_data(const synfig::String& key)
+{
+	if (key=="guide_x" || key=="guide_y")
+	{
+		// Create an undoable action
+		synfigapp::Action::Handle action(synfigapp::Action::create("CanvasMetadataErase"));
+
+		assert(action);
+		if(!action)
+			return;
+
+		action->set_param("canvas",get_canvas());
+		action->set_param("canvas_interface",etl::loose_handle<CanvasInterface>(this));
+		action->set_param("key",key);
+
+		get_instance()->perform_action(action);
+	}
+	else
+	{
+		get_canvas()->erase_meta_data(key);
+	}
+}
 
 // this function goes with find_important_value_descs()
 static int
