@@ -4,12 +4,11 @@ OPTIONS=""
 OPTIONS="$OPTIONS --disable-optimization"
 #OPTIONS="$OPTIONS --disable-debug"
 OPTIONS="$OPTIONS --enable-debug"
-#OPTIONS="$OPTIONS --enable-license-key"
 
 
 BUILDDIR=win32build
 
-[ -e configure ] || ./bootstrap || exit 1
+[ -e configure ] || autoreconf --force --install || exit 1
 
 [ -d $BUILDDIR ] && rm -fr $BUILDDIR
 
